VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package packagepal

Package {packagepal}


Title: Guidelines and Checklists for Building CRAN-Worthy Packages
Version: 0.1.1
Description: Provides essential checklists for R package developers, whether you're creating your first package or beginning a new project. This tool guides you through each step of the development process, including specific considerations for submitting your package to the Comprehensive R Archive Network (CRAN). Simplify your workflow and ensure adherence to best practices with 'packagepal'.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
URL: https://github.com/lddurbin/packagepal
BugReports: https://github.com/lddurbin/packagepal/issues
Imports: cli (≥ 3.6.1), usethis (≥ 2.2.2), utils (≥ 4.2.3)
Suggests: knitr, rmarkdown, testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-02 19:23:25 UTC; leedurbin
Author: Lee Durbin [aut, cre, cph]
Maintainer: Lee Durbin <l.d.durbin@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-02 19:50:02 UTC

packagepal: Guidelines and Checklists for Building CRAN-Worthy Packages

Description

Provides essential checklists for R package developers, whether you're creating your first package or beginning a new project. This tool guides you through each step of the development process, including specific considerations for submitting your package to the Comprehensive R Archive Network (CRAN). Simplify your workflow and ensure adherence to best practices with 'packagepal'.

Author(s)

Maintainer: Lee Durbin l.d.durbin@gmail.com [copyright holder]

See Also

Useful links:


Check-Lists For Either Building A Package Or Submitting To CRAN

Description

A check-list of things you should do when building a R package from scratch, or submitting a package to CRAN.

Usage

checklist(type = "package")

Arguments

type

Load the check-list items for package building (package"), or for submitting to CRAN ("CRAN")?

Value

The id of the new container element, invisibly.

Examples

checklist("CRAN")

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.